## 1.15.1.13 (2023-04-27)

cffi: improve getitem and setitem (#9968)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 1.15.1.12 (2023-04-13)

[cffi] dlopen(None) works when platform != win32 (#10042)

## 1.15.1.11 (2023-04-06)

cffi: fix FFI.string signature (#10012)

Keeps _cffi_backend.pyi consistent with api.pyi

## 1.15.1.10 (2023-03-27)

Add defaults for third-party stubs A-D (#9952)

## 1.15.1.9 (2023-03-27)

[cffi] add some return types (#9949)

## 1.15.1.8 (2023-03-23)

[cffi] cast source can be an int too  (#9930)

[cffi] cast source can be an int too

Co-authored-by: Francesc Elies <francesc.elies@mbbm-ast.com>

Add alternate type for cffi's from_buffer (#9925)

## 1.15.1.7 (2023-02-26)

Improve many `__(a)exit__` annotations (#9696)

## 1.15.1.6 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.15.1.5 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 1.15.1.4 (2023-01-18)

Replace `Any` with `Incomplete` in many places (#9558)

## 1.15.1.3 (2022-11-13)

`cffi`: run stubtest on Windows (#9178)

## 1.15.1.2 (2022-11-09)

All `__nonzero__` are methods that return `bool` (#9139)

## 1.15.1.1 (2022-11-09)

Annotate known magic-method return types (#9131)

## 1.15.1 (2022-09-27)

Bump mypy to 0.981 (#8796)

## 1.15.0 (2022-09-15)

Add type stubs for cffi (#8736)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

